
####################################################################################################
# eltest2step.all is a function to search the minimum of -2LLR by Golden Section Search method
# eltest2step.all calls both eltest2u.all and eltest2v.all and returns the minimum summation of -2LLR
# from eltest2u.all and eltest2v.all
# x    is a non diseased sample
# y    is a diseased sample
# eps  is the smoothing band width. When there are tied data this is important, recommend value = sqrt n <  < qubic root n.
#              (eps added by M Zhou, also use mean.whole2 instead of mean.whole. Similar change to eltest2uv.all.
# tol  is used to determine when to stop the Golden Section Search.
# true is the AUC to be tested, it is the value specified by null hypothesis H0, do not have to be the true value.
####################################################################################################


eltest2step.all <- function(true, x, y, tol=0.001, eps=0.01){
  
  nx <- length(x)
  ny <- length(y)
  est.pauc <- rep(1/nx, nx)%*% mean.whole2(x, y, eps=eps)%*% rep(1/ny, ny)
  
  search.low <- ifelse((min(est.pauc, true)-0.1) >0, (min(est.pauc, true)-0.1), 0)
  
  search.high <- ifelse((max(est.pauc, true)+0.1) <1 , (max(est.pauc, true)+0.1), 1)
  
  grat <- (sqrt(5)-1)/2
  
  d <- grat * (search.high - search.low)
  
  x2 <- search.low + d
  
  x1 <- search.high - d
  
  res1 <- eltest2u.all(x.sample=x, mu=x1, y=y, vvec=rep(1/ny, ny), eps=eps)
  res2 <- eltest2v.all(x.sample=x, mu=true, y=y, uvec=res1$uvec/nx, eps=eps)
  
  fun.x1 <-  res1$"-2LLR" + res2$"-2LLR"
  
  res1 <- eltest2u.all(x.sample=x, mu=x2, y=y, vvec=rep(1/ny, ny), eps=eps)
  res2 <- eltest2v.all(x.sample=x, mu=true, y=y, uvec=res1$uvec/nx, eps=eps)
  
  fun.x2 <-  res1$"-2LLR" + res2$"-2LLR"
  
  err <- 100
  
  numit <- 0
  
  while (err > tol) {
    
    numit <- numit + 1
    
    if (fun.x1 < fun.x2){
      
      xopt <- x1
      
      err <- (1 - grat) * abs((search.high - search.low)/xopt)
      
      if (err > tol) {
        
        search.high <- x2
        
        x2 <- x1
        
        fun.x2 <- fun.x1
        
        d <- grat * (search.high - search.low)
        
        x1 <- search.high - d
        
        
        res1 <- eltest2u.all(x.sample=x, mu=x1, y=y, vvec=rep(1/ny, ny), eps=eps)
        res2 <- eltest2v.all(x.sample=x, mu=true, y=y, uvec=res1$uvec/nx, eps=eps)
        
        fun.x1 <-  res1$"-2LLR" + res2$"-2LLR"
        
      }
    }
    
    else {
      
      xopt <- x2
      
      err <- (1 - grat) * abs((search.high - search.low)/xopt)
      
      if (err > tol) {
        
        search.low <- x1
        
        x1 <- x2
        
        fun.x1 <- fun.x2
        
        d <- grat * (search.high - search.low)
        
        x2 <- search.low + d 
        
        res1 <- eltest2u.all(x.sample=x, mu=x2, y=y, vvec=rep(1/ny, ny), eps=eps)
        res2 <- eltest2v.all(x.sample=x, mu=true, y=y, uvec=res1$uvec/nx, eps=eps)
        
        fun.x2 <-  res1$"-2LLR" + res2$"-2LLR"
        
      }
      
    }
  }
  res1 <- eltest2u.all(x.sample=x, mu=xopt, y=y, vvec=rep(1/ny, ny), eps=eps)
  res2 <- eltest2v.all(x.sample=x, mu=true, y=y, uvec=res1$uvec/nx, eps=eps)
  fun.xopt <-  res1$"-2LLR" + res2$"-2LLR"
  
  return(list('-2LLR'=fun.xopt, Pval = 1 - pchisq(fun.xopt, df=1)))
}
