
####################################################################################################
# eltest2step.p12 is a function to search the minimum of -2LLR by Golden Section Search method
# eltest2step.p12 calls both eltest2up12 and eltest2vp12 and returns the minimum summation of -2LLR
# from eltest2up12 and eltest2vp12
# mean.fun is mean.paucp1 or mean.paucp2, which is chosen based on the pAUC at [p, 1] or [0, p]
# x is a non diseased sample
# y is a diseased sample
# highx is the (1 - p)th quantile 
# p is the False Positive Rate to be included in the Partial AUC at [p, 1] or [0, p]
# truepauc is the Partial AUC to be tested
####################################################################################################

eltest2step.p12 <- function(x, highx, y, vp, truepauc, tol=.001, eps){
  
  if (vp[1]==0 & vp[2] > 0 & vp[2] < 1){
    
    p <- vp[2]
    
    mean.fun <- mean.paucp2
  }
  
  if (vp[2]==1 & vp[1] > 0 & vp[1] < 1){
    
    p <- vp[1]
    
    mean.fun <- mean.paucp1
  }

  nx <- length(x)
  
  ny <- length(y)
  
  est.pauc <- rep(1/nx, nx)%*% mean.fun(x, highx, eps, y)%*% rep(1/ny, ny)
  
  search.low <- ifelse((min(est.pauc, truepauc)-0.1) >0, (min(est.pauc, truepauc)-0.1), 0)
  
  search.high <- ifelse((max(est.pauc, truepauc)+0.1) <1 , (max(est.pauc, truepauc)+0.1), 1)
  
  grat <- (sqrt(5)-1)/2
  
  d <- grat * (search.high - search.low)
  
  x2 <- search.low + d
  
  x1 <- search.high - d
  
  
  res1 <- eltest2up12(mean.fun, highx, x.sample=x, mu=c(1-p, x1), y, vvec=rep(1/ny, ny), eps)
  #res1 <- eltest2up12(mean.fun, highx, x.sample=x, mu=c(p, x1), y, vvec=rep(1/ny, ny))
  res2 <- eltest2vp12(mean.fun, highx, x.sample=x, mu=truepauc, y, res1$uvec/nx, eps)
  
  fun.x1 <-  res1$"-2LLR" + res2$"-2LLR"
  
  res1 <- eltest2up12(mean.fun, highx, x.sample=x, mu=c(1-p, x2), y, vvec=rep(1/ny, ny), eps)
  #res1 <- eltest2up12(mean.fun, highx, x.sample=x, mu=c(p, x2), y, vvec=rep(1/ny, ny))
  res2 <- eltest2vp12(mean.fun, highx, x.sample=x, mu=truepauc, y, res1$uvec/nx, eps)
  
  fun.x2 <-  res1$"-2LLR" + res2$"-2LLR"
  
  err <- 100
  
  numit <- 0
  
  while (err > tol) {
    
    numit <- numit + 1
    
    if (fun.x1 < fun.x2){
      
      xopt <- x1
      
      err <- (1 - grat) * abs((search.high - search.low)/xopt)
      
      if (err > tol) {
        
        search.high <- x2
        
        x2 <- x1
        
        fun.x2 <- fun.x1
        
        d <- grat * (search.high - search.low)
        
        x1 <- search.high - d
        
        
        res1 <- eltest2up12(mean.fun, highx, x.sample=x, mu=c(1-p, x1), y, vvec=rep(1/ny, ny), eps)
        #res1 <- eltest2up12(mean.fun, highx, x.sample=x, mu=c(p, x1), y, vvec=rep(1/ny, ny))
        res2 <- eltest2vp12(mean.fun, highx, x.sample=x, mu=truepauc, y, res1$uvec/nx, eps)
        
        fun.x1 <-  res1$"-2LLR" + res2$"-2LLR"
        
      }
    }
    
    else {
      
      xopt <- x2
      
      err <- (1 - grat) * abs((search.high - search.low)/xopt)
      
      if (err > tol) {
        
        search.low <- x1
        
        x1 <- x2
        
        fun.x1 <- fun.x2
        
        d <- grat * (search.high - search.low)
        
        x2 <- search.low + d 
        
        res1 <- eltest2up12(mean.fun, highx, x.sample=x, mu=c(1-p, x2), y, vvec=rep(1/ny, ny), eps)
        # res1 <- eltest2up12(mean.fun, highx, x.sample=x, mu=c(p, x2), y, vvec=rep(1/ny, ny))
        res2 <- eltest2vp12(mean.fun, highx, x.sample=x, mu=truepauc, y, res1$uvec/nx, eps)
        
        fun.x2 <-  res1$"-2LLR" + res2$"-2LLR"
        
      }
      
    } 
    
  }
  
  
  res1 <- eltest2up12(mean.fun, highx, x.sample=x, mu=c(1-p, xopt), y, vvec=rep(1/ny, ny), eps)
  # res1 <- eltest2up12(mean.fun, highx, x.sample=x, mu=c(p, xopt), y, vvec=rep(1/ny, ny))
  res2 <- eltest2vp12(mean.fun, highx, x.sample=x, mu=truepauc, y, res1$uvec/nx, eps)
  
  return("-2LLR"= res1$"-2LLR" + res2$"-2LLR")
  
}


