\name{eltest2step}
\alias{eltest2step}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Empirical likelihood test for percentiles at (1-p2) and (1-p1), and pAUC at (p1, p2). P1 and p2 are false positive rates, p1 < p2
}
\description{
Compute the empirical likelihood ratio test with three parameters: percentiles at (1-p2) and (1-p1), and pAUC fixed at \eqn{pAUC_0}
}
\usage{
eltest2step(x, ab= vector("numeric",2), y, p1, p2, truepauc, tol=.001, eps)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{ab}{
a vector of two percentiles at \eqn{(1-p2)} and \eqn{(1-p1)}, \eqn{0 < p1 < p2 < 1}
}
  \item{x}{
a sample of test results from non-diseased population
}
  \item{y}{
a sample of test results from diseased population
}
\item{p1}{
the smaller false positive rate to be included in pAUC
}
\item{p2}{
the larger false positive rate to be included in pAUC
}
  \item{truepauc}{
the pAUC to be tested
}
  \item{tol}{
the maximum distance between the current guess and the current range on Golden Section Search Optimization method
}
  \item{eps}{
a smoothing parameter
}
}
\details{
The function applys the 'ELseesaw' algorithm described in the reference to minimize the empirical likelihood ratio test. 
"-2LLR" may be positive infinite if the tested values of the parameters are far away from the true values.
}
\value{
\item{"-2LLR"}{the -2 loglikelihood ratio; approximate chisq distribution with three degree of freedom under \eqn{H_0}}
}
\references{
Statistical Inference on Partial Area Under ROC Curves by Empirical Likelihood Method
}
\author{
Yumin Zhao
}
%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{
mux <- 0
stddx <- 1
muy <- 1
stddy <- 1

p1 <- 0.05 
p2 <- 0.5

q1 <- qnorm(p=1-p2, mean=mux, sd=stddx)
q2 <- qnorm(p=1-p1, mean=mux, sd=stddx)

  rp<-function(p, mux, stddx, muy, stddy)
  {
    y<-1-pnorm(qnorm(1-p, mux, stddx), muy, stddy)
    y
  }
###ture pAUC at (p1, p2)  
truepauc<-integrate(rp, mux=mux, stddx=stddx, muy=muy, stddy=stddy,lower=p1,upper=p2)$value
    
nx <- 40
ny <- 30
   
x <- rnorm(nx, mux, stddx)
y <- rnorm(ny, muy, stddy)   
eltest2step(ab=c(q1, q2), x=x, y=y, truepauc=truepauc, p1=p1, p2=p2, tol=0.001, eps=1/nx)
     
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
%\keyword{ ~kwd1 }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
