\name{neighb.xy3p12}
\alias{neighb.xy3p12}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Empirical likelihood test for pAUC at (0, p) or (p, 1)
}
\description{
Compute the empirical likelihood ratio with pAUC fixed at \eqn{pAUC_0}
}
\usage{
neighb.xy3p12(vp, x, y, true, tol = 0.001, eps, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{vp}{
a vector of the False Postive Rate cutting point for pAUC; vp = (0, p) or vp = (p, 1)
}
  \item{x}{
a sample of test results from non-diseased population
}
  \item{y}{
a sample of test results from diseased population
}
  \item{true}{
the pAUC to be tested
}
  \item{tol}{
the maximum distance between the current guess and the current range on Golden Section Search Optimization method
}
  \item{eps}{
a smoothing parameter
}
  \item{\dots}{
additional arguments, if any, to pass to fun
}
}
\details{
This function seaches the minimum of the empirical likehihood ratio test statistics among the consecutive non-diseased sample points. 
Since the test statistics is a piecewise constant function of the quantile for (1 - p), the minimum is easily found if searching 
starts at some strategical quantile such as the sample quantile at (1 - p)
}
\value{
\item{"-2LLR"}{the -2 loglikelihood ratio; approximate chisq distribution under \eqn{H_0}}
\item{Pval}{the observed P-value by chi-square approximation}
}
\references{
The Paritial Area Under ROC Curves by Empirical Likelihood Method
}
\author{
Yumin Zhao
}
%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{
p <- 0.4

rate.x <- 1
rate.y <- 0.25
  
  rp.exp2<-function(p, rate.x, rate.y)
  { 
    y<- 1- pexp(qexp(1-p, rate=rate.x), rate=rate.y)
    y
  }
  
p1 <- 0
p2 <- p
###ture pAUC at (0, p)
truepauc <- integrate(rp.exp2, rate.x, rate.y,lower=p1,upper=p2)$value 

nx <- 50
ny <- 40

x <- rexp(nx, rate.x)
y <- rexp(ny, rate.y)  
neighb.xy3p12(vp =c(p1, p2), x=x, y=y, true=truepauc, tol=0.001, eps=1/nx)
 
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
%\keyword{ ~kwd1 }
%\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
